@@ -15,7 +15,7 @@ import notmuch2._query as querymod
 import notmuch2._tags as tags
 
 
-__all__ = ['Database', 'AtomicContext', 'DbRevision']
+__all__ = ['Database', 'AtomicContext', 'DbRevision', 'IndexOptions']
 
 
 def _config_pathname():
@@ -285,6 +285,30 @@ class Database(base.NotmuchObject):
             raise errors.NotmuchError(ret)
         self.closed = True
 
+    def reopen(self, mode=None):
+        """Reopen an opened notmuch database.
+
+        :param mode: Mode to reopen the database with. When None, the previously
+           active mode is preserved.
+        :type mode: :attr:`MODE`, str, or None.
+
+        This is useful e.g. for:
+        - switching the mode between read-only and read-write
+        - recovering from OperationInvalidatedError
+        """
+        if isinstance(mode, str):
+            try:
+                mode = self.STR_MODE_MAP[mode]
+            except KeyError:
+                raise ValueError('Invalid mode: %s' % mode)
+        else:
+            mode = mode or self.mode
+        self.mode = mode
+
+        ret = capi.lib.notmuch_database_reopen(self._db_p, mode.value)
+        if ret != capi.lib.NOTMUCH_STATUS_SUCCESS:
+            raise errors.NotmuchError(ret)
+
     def __enter__(self):
         return self
 
@@ -351,7 +375,7 @@ class Database(base.NotmuchObject):
         The returned context manager can be used to perform atomic
         operations on the database.
 
-        .. note:: Unlinke a traditional RDBMS transaction this does
+        .. note:: Unlike a traditional RDBMS transaction this does
            not imply durability, it only ensures the changes are
            performed atomically.
 
@@ -416,7 +440,7 @@ class Database(base.NotmuchObject):
         :raises XapianError: A Xapian exception occurred.
         :raises FileError: The file referred to by ``pathname`` could
            not be opened.
-        :raises FileNotEmailError: The file referreed to by
+        :raises FileNotEmailError: The file referred to by
            ``pathname`` is not recognised as an email message.
         :raises ReadOnlyDatabaseError: The database is opened in
            READ_ONLY mode.
@@ -833,7 +857,7 @@ class IndexOptions(base.NotmuchObject):
         """The decryption policy.
 
         This is an enum from the :class:`DecryptionPolicy`.  See the
-        `index.decrypt` section in :man:`notmuch-config` for details
+        `index.decrypt` section in :any:`notmuch-config(1)` for details
         on the options.  **Do not set this to
         :attr:`DecryptionPolicy.TRUE`** without considering the
         security of your index.
