@@ -212,6 +212,10 @@ _notmuch_message_create (const void *talloc_owner,
 	if (status)
 	    *status = NOTMUCH_PRIVATE_STATUS_NO_DOCUMENT_FOUND;
 	return NULL;
+    } catch (const Xapian::DatabaseModifiedError &error) {
+	if (status)
+	    *status = NOTMUCH_PRIVATE_STATUS_OPERATION_INVALIDATED;
+	return NULL;
     }
 
     return _notmuch_message_create_for_document (talloc_owner, notmuch,
@@ -293,7 +297,7 @@ _notmuch_message_create_for_message_id (notmuch_database_t *notmuch,
 			       "A Xapian exception occurred creating message: %s\n",
 			       error.get_msg ().c_str ());
 	notmuch->exception_reported = true;
-	*status_ret = NOTMUCH_PRIVATE_STATUS_XAPIAN_EXCEPTION;
+	*status_ret = _notmuch_xapian_error_private ();
 	return NULL;
     }
 
@@ -719,8 +723,6 @@ _notmuch_message_remove_terms (notmuch_message_t *message, const char *prefix)
 	    /* Ignore failure to remove non-existent term. */
 	}
     }
-
-    _notmuch_message_invalidate_metadata (message, "property");
 }
 
 
@@ -1207,7 +1209,7 @@ notmuch_message_get_flag_st (notmuch_message_t *message,
 	    _notmuch_message_ensure_metadata (message, NULL);
     } catch (Xapian::Error &error) {
 	LOG_XAPIAN_EXCEPTION (message, error);
-	return NOTMUCH_STATUS_XAPIAN_EXCEPTION;
+	return _notmuch_xapian_error ();
     }
 
     *is_set = NOTMUCH_TEST_BIT (message->flags, flag);
@@ -1429,7 +1431,7 @@ _notmuch_message_delete (notmuch_message_t *message)
 	}
     } catch (Xapian::Error &error) {
 	LOG_XAPIAN_EXCEPTION (message, error);
-	return NOTMUCH_STATUS_XAPIAN_EXCEPTION;
+	return _notmuch_xapian_error ();
     }
     if (count > 0) {
 	/* reintroduce a ghost in its place because there are still
@@ -1460,7 +1462,7 @@ _notmuch_message_delete (notmuch_message_t *message)
 	    }
 	} catch (Xapian::Error &error) {
 	    LOG_XAPIAN_EXCEPTION (message, error);
-	    return NOTMUCH_STATUS_XAPIAN_EXCEPTION;
+	    return _notmuch_xapian_error ();
 	}
 
     }
@@ -1530,7 +1532,7 @@ _notmuch_message_add_term (notmuch_message_t *message,
 	_notmuch_message_invalidate_metadata (message, prefix_name);
     } catch (Xapian::Error &error) {
 	LOG_XAPIAN_EXCEPTION (message, error);
-	status = NOTMUCH_PRIVATE_STATUS_XAPIAN_EXCEPTION;
+	status = _notmuch_xapian_error_private ();
     }
 
   DONE:
@@ -1641,7 +1643,7 @@ _notmuch_message_has_term (notmuch_message_t *message,
 	    ! strcmp ((*i).c_str (), term))
 	    out = true;
     } catch (Xapian::Error &error) {
-	status = NOTMUCH_PRIVATE_STATUS_XAPIAN_EXCEPTION;
+	status = _notmuch_xapian_error_private ();
     }
     talloc_free (term);
 
@@ -1678,7 +1680,7 @@ notmuch_message_add_tag (notmuch_message_t *message, const char *tag)
 
     } catch (Xapian::Error &error) {
 	LOG_XAPIAN_EXCEPTION (message, error);
-	return NOTMUCH_STATUS_XAPIAN_EXCEPTION;
+	return _notmuch_xapian_error ();
     }
 
     return NOTMUCH_STATUS_SUCCESS;
@@ -1712,7 +1714,7 @@ notmuch_message_remove_tag (notmuch_message_t *message, const char *tag)
 	    _notmuch_message_sync (message);
     } catch (Xapian::Error &error) {
 	LOG_XAPIAN_EXCEPTION (message, error);
-	return NOTMUCH_STATUS_XAPIAN_EXCEPTION;
+	return _notmuch_xapian_error ();
     }
 
     return NOTMUCH_STATUS_SUCCESS;
